function output = DB2params(dbFile)
%this function reads the SQL DB outputted by params2SQL
%and converts it back to a structure like that first passed to params2SQL
%Expects the file path to the SQLite DB file

%https://almworks.com/sqlite4java/javadoc/com/almworks/sqlite4java/SQLiteStatement.html
a=java.util.logging.Logger.getLogger("com.almworks.sqlite4java");
a.setLevel(java.util.logging.Level.OFF) %turn off Java logging
db = com.almworks.sqlite4java.SQLiteConnection(java.io.File(dbFile));
db.open;

% Prepare an SQL query statement
stmt = db.prepare("SELECT name FROM sqlite_master WHERE type='table'");
 
% Step through the result set rows
cnt = 1;
while stmt.step
   tables(cnt)  = stmt.columnString(0); % column #1
   cnt = cnt + 1;
end
tables = string(tables);


stmt.dispose % Cleanup statement

%get column names and data from Info table
stmt = db.prepare('select * from Info');
cnt = 1;
stmt.step;
numCol = stmt.columnCount;
stmt.reset;
while stmt.step
    for i=0:numCol-1
       infoData(i+1,cnt) = {stmt.columnValue(i)}; 
       if cnt == 1
           infoFields(i+1) = stmt.getColumnName(i);
       end
    end
    cnt = cnt + 1;
end
infoFields = string(infoFields)';
infoData = infoData'; %necessary later

%generate field names for output structure
k = ~(strcmpi(tables, 'Info'));
tables = tables(k); %list of tables other than Info

for t=1:length(tables)
    
    stmt = db.prepare(strcat("select * from ",tables(t)));
    cnt = 1;
    stmt.step;
    numCol = stmt.columnCount;
    stmt.reset;
    while stmt.step
        for i=0:numCol-1
           data(i+1,cnt) = {stmt.columnValue(i)}; 
        end
        cnt = cnt + 1;
    end
    
    %rearrange and cleanup the data
    %then add it to the rest
    infoData = [infoData arrayfun(@(x) cell2mat(data(x,:))',1:numCol,'un',0)'];
    infoFields = [infoFields tables(t)];
    clear data
end

db.dispose %close the db connection

%find which column has the rotation matrices and covnert them from vector
%to 3x3 matrix
k = strcmpi(infoFields,'Rot');
infoData(:,k) = arrayfun(@(x) reshape(cell2mat(infoData(x,k))',3,3),1:length(infoFields(:,1)),'un',0);

%convert time from Julian date to datetime
k = strcmpi(infoFields,'time');
infoData(:,k) = arrayfun(@(x) datetime(infoData{x,k},'convertfrom','juliandate'),1:length(infoFields(:,1)),'un',0);

%get all the data into cells then create the output structure
output = cell2struct(infoData',cellstr(infoFields)');

end