function Out = in_grid(Rot,Bot,Lat,Lon)
% check to see if a point is contained within the grid
% Input arguments:
%       Rot = rotation matrix for the grid
%       Bot = 'latitude' of the bottom of the grid
%       Lat = Latitude of input points
%       Lon = Longitude of input points
% Output arguments:
%       Out = boolean true if inside grid
% -------------------------------------------------------------------------

if any(size(Lat) ~= size(Lon))
  error('Lat and Lon must be arrays of the same size.')
end

Crd = sphcart([ones(numel(Lat),1),deg2rad(Lat(:)),deg2rad(Lon(:))]);


C = Rot*[0 0 1.7e7]';
O = zeros(3,1);

% inside cone
h=((Crd-O')*(C./norm(C)));
a = h.*tan(deg2rad(90-Bot));
b = sqrt(sum(((Crd-O') - h*(C'./norm(C))).^2,2));
Out = reshape(a>b,size(Lat));

end

function Cart = sphcart( Sph )
% Function to convert spherical to cartesian coordinates
%    Cart = sphcart( Sph )
% Input arguments:
%    Sph  = Spherical coordinates, [rad(m),lat(rad),lon(rad);...]
% Output arguments:
%    Cart =Cartesian coordinates, [x,y,z;...]
% Notes:
%    For geographic coordinates, x points to Greenwich, z to the north pole
%
% See also CARTSPH
% -------------------------------------------------------------------------

Cart = [ Sph(:,1).*cos(Sph(:,2)).*cos(Sph(:,3)),...
         Sph(:,1).*cos(Sph(:,2)).*sin(Sph(:,3)),...
         Sph(:,1).*sin(Sph(:,2)) ]

end