function params2DB(Params,file)
%This function converts the Params structure from A-CHAIM into a SQLite DB
%Expects the Params structure as outputted by A-CHAIM 
%(saved to the output_YYYYMMDD_HHmmSS.mat files)

dbFile = file;

%Convert params structure to cell array and get the field names
params = struct2cell(Params);
fields = fieldnames(Params);

%convert dates to julian date
dk = strcmpi(string(fields),'time');
params(dk,:) = cellfun(@juliandate,params(dk,:),'un',0);

%Determine which fields will be put into the 'Info' table
%and which will need their own tables
infoIndD = cell2mat(cellfun(@(x) isscalar(x),params(:,1),'un',0));
infoIndC = cell2mat(cellfun(@(x) ischar(x),params(:,1),'un',0));
tableInd = ~(infoIndC | infoIndD);

%String to create 'Info' table
a = strjoin(string(cellfun(@(x) strcat(x,' TEXT,'),fields(infoIndC),'un',0)));
b = strjoin(string(cellfun(@(x) strcat(x,' INTEGER,'),fields(infoIndD(~dk)),'un',0))); %ignoring date here
c = strcat(fields(dk)," REAL");
createInfo = strcat('create table if not exists Info( ',strcat(a,b,c));

%create info data and fields
infoData = params(infoIndC | infoIndD,:)';
infoFields = fields(infoIndC | infoIndD);

%create an extra column with an integer code for the calculation types
calcTypes = {'logadd','static','prop','add','logabs','abs'};
k = find(strcmp(infoFields, {'Type'}));
types = categorical(infoData(:,k), calcTypes);

infoData(:,end+1) = num2cell(double(types));
infoFields = [infoFields; {'TypeVal'}];

%add new field to create table query
createInfo = strcat(createInfo, ',  TypeVal INTEGER);');

%"overwrite" the old DB file
if exist(dbFile,'file')
    delete(dbFile);
end
conn = sqlite(dbFile,'create');

exec(conn,createInfo); %create the info table
insert(conn,'Info',infoFields,infoData); %populate the info table

%generate tables and input the other data into the database
tableInd = find(tableInd);

%get characteristic names
dn = strcmpi(string(fields),'name');

%loop through remaining fields
for i=1:length(tableInd)
   
    %create the table
    a = char(cellfun(@(x) strcat(x,' REAL,'),params(dn,:),'un',0))'; %generate column names
    exec(conn,strcat("create table if not exists ", fields(tableInd(i)),'(',a(1:end-1),');')); %create table
    
    %must make all arrays (columns) the same length
    m = max(cell2mat(cellfun(@(x) length(x(:)),params(tableInd(i),:),'un',0))); %get the largest array size
    dataIn = cellfun(@(x) [x(:);zeros(m-length(x(:)),1)+NaN],params(tableInd(i),:),'un',0);
    insert(conn,string(fields(tableInd(i))),params(dn,:),dataIn); %populate table
    
end

close(conn);
end
